@@ -76,6 +76,9 @@ class GemBox:
         
         # Gembox Messages
         for index, mail in enumerate(self.Mails):
+            # Message ID
+            result.write(f"[{mail.ID}]\n")
+
             # Metadata
             if len(mail.Senders) > 0:
                 result.write("Senders: ")
